==> bibledit-0.7.tar.gz: bibledit-0.7/src/configuration.cpp <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "libraries.h"
#include "configuration.h"
#include "utilities.h"
#include "config.h"
#include "directories.h"


Configuration::Configuration (GtkWindow *window)
{
  // Read the configuration file, if there is any. Add the bits that are missing.
  ReadText rc (bibleditrc (), true);
  screen_resolution_changed = false;
  for (unsigned int i = 0; i <= 1000; i++)
    {
      switch (i)
        {
        case 2:
          {
            if (i < rc.lines.size ())
              {
                edit_note_standard_text_one = rc.lines[i];
              }
            else
              {
                edit_note_standard_text_one.clear();
              }
            break;
          }
        case 3:
          {
            if (i < rc.lines.size ())
              {
                edit_note_standard_text_two = rc.lines[i];
              }
            else
              {
                edit_note_standard_text_two.clear ();
              }
            break;
          }
        case 4:
          {
            if (i < rc.lines.size ())
              {
                edit_note_standard_text_three = rc.lines[i];
              }
            else
              {
                edit_note_standard_text_three.clear();
              }
            break;
          }
        case 5:
          {
            GdkScreen *screen;
            screen = gtk_window_get_screen (window);
            gint width;
            width = gdk_screen_get_width (screen);
            if (i < rc.lines.size ())
              {
                screen_width = convert_to_int (rc.lines[i]);
              }
            else
              {
                screen_width = 0;
              }
            if (screen_width != width)
              {
                screen_resolution_changed = true;
                screen_width = width;
              }
            break;
          }
        case 6:
          {
            GdkScreen *screen;
            screen = gtk_window_get_screen (window);
            gint height;
            height = gdk_screen_get_height (screen);
            if (i < rc.lines.size ())
              {
                screen_height = convert_to_int (rc.lines[i]);
              }
            else
              {
                screen_height = 0;
              }
            if (screen_height != height)
              {
                screen_resolution_changed = true;
                screen_height = height;
              }
            break;
          }
        case 7:
          {
            bool take_default = false;
            if (i < rc.lines.size ())
              {
                window_width = convert_to_int (rc.lines[i]);
              }
            else
              {
                take_default = true;
              }
            if (screen_resolution_changed || take_default)
              {
                window_width = screen_width * 95 / 100;
              }
            break;
          }
        case 8:
          {
            bool take_default = false;
            if (i < rc.lines.size ())
              {
                window_height = convert_to_int (rc.lines[i]);
              }
            else
              {
                take_default = true;
              }
            if (screen_resolution_changed || take_default)
              {
                window_height = screen_height * 90 / 100;
              }
            break;
          }
        case 9:
          {
            bool take_default = false;
            if (i < rc.lines.size ())
              {
                window_x_position = convert_to_int (rc.lines[i]);
              }
            else
              {
                take_default = true;
              }
            if (screen_resolution_changed || take_default)
              {
                window_x_position = 0;
              }
            break;
          }
        case 10:
          {
            bool take_default = false;
            if (i < rc.lines.size ())
              {
                window_y_position = convert_to_int (rc.lines[i]);
              }
            else
              {
                take_default = true;
              }
            if (screen_resolution_changed || take_default)
              {
                window_y_position = 0;
              }
            break;
          }
        case 11:
          {
            bool take_default = false;
            if (i < rc.lines.size ())
              {
                hpane_position = convert_to_int (rc.lines[i]);
              }
            else
              {
                take_default = true;
              }
            if (screen_resolution_changed || take_default)
              {
                hpane_position = window_width * 87 / 100;
              }
            // Prevents editor from becoming invisible altogether,
            // prompting users to ask for support.
            if (hpane_position < 300) hpane_position = 300;
            break;
          }
        case 12:
          {
            bool take_default = false;
            if (i < rc.lines.size ())
              {
                vpane_position = convert_to_int (rc.lines[i]);
              }
            else
              {
                take_default = true;
              }
            if (screen_resolution_changed || take_default)
              {
                vpane_position = window_height * 50 / 100;
              }
            // Prevents editor from becoming invisible altogether,
            // prompting users to ask for support.
            if (vpane_position < 200) vpane_position = 200;
            break;
          }
        case 13:
          {
            if (i < rc.lines.size ())
              {
                book_opened = rc.lines[i];
              }
            else
              {
                book_opened.clear ();
              }
            break;
          }
        case 14:
          {
            if (i < rc.lines.size ())
              {
                chapter_opened = rc.lines[i];
              }
            else
              {
                chapter_opened = "1";
              }
            break;
          }
        case 15:
          {
            if (i < rc.lines.size ())
              {
                verse_opened = rc.lines[i];
              }
            else
              {
                verse_opened = "1";
              }
            break;
          }

        case 16:
          {
            if (i < rc.lines.size ())
              {
                edit_note_standard_text_four = rc.lines[i];
              }
            else
              {
                edit_note_standard_text_four.clear ();
              }
            break;
          }

        case 17:
          {
            if (i < rc.lines.size ())
              {
                searchspecial_containword = convert_to_bool (rc.lines[i]);
              }
            else
              {
                searchspecial_containword = false;
              }
            break;
          }

        case 18:
          {
            if (i < rc.lines.size ())
              {
                find_searchword = rc.lines[i];
              }
            else
              {
                find_searchword.clear ();
              }
            break;
          }

        case 19:
          {
            if (i < rc.lines.size ())
              {
                find_replaceword = rc.lines[i];
              }
            else
              {
                find_replaceword.clear ();
              }
            break;
          }

        case 20:
          {
            if (i < rc.lines.size ())
              {
                references_file = rc.lines[i];
              }
            else
              {
                references_file.clear ();
              }
            break;
          }

        case 21:
          {
            if (i < rc.lines.size ())
              {
                companion_enabled = convert_to_bool (rc.lines[i]);
              }
            else
              {
                companion_enabled = false;
              }
            break;
          }

        case 22:
          {
            if (i < rc.lines.size ())
              {
                companion_remote_enabled_reuse = convert_to_bool (rc.lines[i]);
              }
            else
              {
                companion_remote_enabled_reuse = false;
              }
            break;
          }

        case 23:
          {
            if (i < rc.lines.size ())
              {
                companion_remote_name_reuse = rc.lines[i];
              }
            else
              {
                companion_remote_name_reuse.clear ();
              }
            break;
          }

        case 24:
          {
            if (i < rc.lines.size ())
              {
                editor_font_name = rc.lines[i];
              }
            else
              {
                editor_font_name = "Sans 14";
              }
            break;
          }

        case 25:
          {
            if (i < rc.lines.size ())
              {
                import_references_searchword = rc.lines[i];
              }
            else
              {
                import_references_searchword.clear ();
              }
            break;
          }

        case 26:
          {
            if (i < rc.lines.size ())
              {
                project = rc.lines[i];
              }
            else
              {
                project.clear ();
              }
            break;
          }

        case 27:
          {
            if (i < rc.lines.size ())
              {
                case_sensitive_search = convert_to_bool (rc.lines[i]);
              }
            else
              {
                case_sensitive_search = false;
              }
            break;
          }

        }
    }
}


Configuration::~Configuration ()
{
  // If the object goes out of scope, it saves the configuration.
  vector < string > output;
  output.push_back (VERSION);
  output.
    push_back
    ("There is no need for editing this file, because it is maintained by bibledit");
  output.push_back (edit_note_standard_text_one);
  output.push_back (edit_note_standard_text_two);
  output.push_back (edit_note_standard_text_three);
  output.push_back (convert_to_string (screen_width));
  output.push_back (convert_to_string (screen_height));
  output.push_back (convert_to_string (window_width));
  output.push_back (convert_to_string (window_height));
  output.push_back (convert_to_string (window_x_position));
  output.push_back (convert_to_string (window_y_position));
  output.push_back (convert_to_string (hpane_position));
  output.push_back (convert_to_string (vpane_position));
  output.push_back (book_opened);
  output.push_back (chapter_opened);
  output.push_back (verse_opened);
  output.push_back (edit_note_standard_text_four);
  output.push_back (convert_to_string (searchspecial_containword));
  output.push_back (find_searchword);
  output.push_back (find_replaceword);
  output.push_back (references_file);
  output.push_back (convert_to_string (companion_enabled));
  output.push_back (convert_to_string (companion_remote_enabled_reuse));
  output.push_back (companion_remote_name_reuse);
  output.push_back (editor_font_name);
  output.push_back (import_references_searchword);
  output.push_back (project);
  output.push_back (convert_to_string (case_sensitive_search));
  write_lines (bibleditrc (), output);
}


string
Configuration::bibleditrc ()
{
  // Returns the full name of the ~/<root>/settings configuration file.
  // E.g.: /home/joe/.bibledit/settings
  string bibledit_directory = directories_get_root ();
  return g_build_filename (bibledit_directory.c_str(), "settings", NULL);
}

==> bibledit-0.9.tar.gz: bibledit-0.9/src/configuration.cpp <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "libraries.h"
#include "configuration.h"
#include "utilities.h"
#include "config.h"
#include "directories.h"
#include "java.h"


Configuration::Configuration (GtkWindow *window)
{
  // Read the configuration file, if there is any. Add the bits that are missing.
  ReadText rc (bibleditrc (), true);
  screen_resolution_changed = false;
  for (unsigned int i = 0; i <= 1000; i++)
    {
      switch (i)
        {
        case 2:
          {
            if (i < rc.lines.size ())
              {
                edit_note_standard_text_one = rc.lines[i];
              }
            else
              {
                edit_note_standard_text_one.clear();
              }
            break;
          }
        case 3:
          {
            if (i < rc.lines.size ())
              {
                edit_note_standard_text_two = rc.lines[i];
              }
            else
              {
                edit_note_standard_text_two.clear ();
              }
            break;
          }
        case 4:
          {
            if (i < rc.lines.size ())
              {
                edit_note_standard_text_three = rc.lines[i];
              }
            else
              {
                edit_note_standard_text_three.clear();
              }
            break;
          }
        case 5:
          {
            GdkScreen *screen;
            screen = gtk_window_get_screen (window);
            gint width;
            width = gdk_screen_get_width (screen);
            if (i < rc.lines.size ())
              {
                screen_width = convert_to_int (rc.lines[i]);
              }
            else
              {
                screen_width = 0;
              }
            if (screen_width != width)
              {
                screen_resolution_changed = true;
                screen_width = width;
              }
            break;
          }
        case 6:
          {
            GdkScreen *screen;
            screen = gtk_window_get_screen (window);
            gint height;
            height = gdk_screen_get_height (screen);
            if (i < rc.lines.size ())
              {
                screen_height = convert_to_int (rc.lines[i]);
              }
            else
              {
                screen_height = 0;
              }
            if (screen_height != height)
              {
                screen_resolution_changed = true;
                screen_height = height;
              }
            break;
          }
        case 7:
          {
            bool take_default = false;
            if (i < rc.lines.size ())
              {
                window_width = convert_to_int (rc.lines[i]);
              }
            else
              {
                take_default = true;
              }
            if (screen_resolution_changed || take_default)
              {
                window_width = screen_width * 95 / 100;
              }
            break;
          }
        case 8:
          {
            bool take_default = false;
            if (i < rc.lines.size ())
              {
                window_height = convert_to_int (rc.lines[i]);
              }
            else
              {
                take_default = true;
              }
            if (screen_resolution_changed || take_default)
              {
                window_height = screen_height * 90 / 100;
              }
            break;
          }
        case 9:
          {
            bool take_default = false;
            if (i < rc.lines.size ())
              {
                window_x_position = convert_to_int (rc.lines[i]);
              }
            else
              {
                take_default = true;
              }
            if (screen_resolution_changed || take_default)
              {
                window_x_position = 0;
              }
            break;
          }
        case 10:
          {
            bool take_default = false;
            if (i < rc.lines.size ())
              {
                window_y_position = convert_to_int (rc.lines[i]);
              }
            else
              {
                take_default = true;
              }
            if (screen_resolution_changed || take_default)
              {
                window_y_position = 0;
              }
            break;
          }
        case 11:
          {
            bool take_default = false;
            if (i < rc.lines.size ())
              {
                hpane_position = convert_to_int (rc.lines[i]);
              }
            else
              {
                take_default = true;
              }
            if (screen_resolution_changed || take_default)
              {
                hpane_position = window_width * 87 / 100;
              }
            // Prevents editor from becoming invisible altogether,
            // prompting users to ask for support.
            if (hpane_position < 300) hpane_position = 300;
            break;
          }
        case 12:
          {
            bool take_default = false;
            if (i < rc.lines.size ())
              {
                vpane_position = convert_to_int (rc.lines[i]);
              }
            else
              {
                take_default = true;
              }
            if (screen_resolution_changed || take_default)
              {
                vpane_position = window_height * 50 / 100;
              }
            // Prevents editor from becoming invisible altogether,
            // prompting users to ask for support.
            if (vpane_position < 200) vpane_position = 200;
            break;
          }
        case 13:
          {
            if (i < rc.lines.size ())
              {
                book_opened = rc.lines[i];
              }
            else
              {
                book_opened.clear ();
              }
            break;
          }
        case 14:
          {
            if (i < rc.lines.size ())
              {
                chapter_opened = rc.lines[i];
              }
            else
              {
                chapter_opened = "1";
              }
            break;
          }
        case 15:
          {
            if (i < rc.lines.size ())
              {
                verse_opened = rc.lines[i];
              }
            else
              {
                verse_opened = "1";
              }
            break;
          }

        case 16:
          {
            if (i < rc.lines.size ())
              {
                edit_note_standard_text_four = rc.lines[i];
              }
            else
              {
                edit_note_standard_text_four.clear ();
              }
            break;
          }

        case 17:
          {
            if (i < rc.lines.size ())
              {
                searchspecial_containword = convert_to_bool (rc.lines[i]);
              }
            else
              {
                searchspecial_containword = false;
              }
            break;
          }

        case 18:
          {
            if (i < rc.lines.size ())
              {
                find_searchword = rc.lines[i];
              }
            else
              {
                find_searchword.clear ();
              }
            break;
          }

        case 19:
          {
            if (i < rc.lines.size ())
              {
                find_replaceword = rc.lines[i];
              }
            else
              {
                find_replaceword.clear ();
              }
            break;
          }

        case 20:
          {
            if (i < rc.lines.size ())
              {
                references_file = rc.lines[i];
              }
            else
              {
                references_file.clear ();
              }
            break;
          }

        case 21:
          {
            if (i < rc.lines.size ())
              {
                companion_enabled = convert_to_bool (rc.lines[i]);
              }
            else
              {
                // Default = on = hassle-free.
                companion_enabled = true;
              }
            break;
          }

        case 22:
          {
            if (i < rc.lines.size ())
              {
                bibletime_enabled = convert_to_bool (rc.lines[i]);
              }
            else
              {
                // Default = on > hassle-free.
                bibletime_enabled = true;
              }
            break;
          }

        case 23:
          {
            if (i < rc.lines.size ())
              {
                export_to_bibleworks_filename = rc.lines[i];
              }
            else
              {
                export_to_bibleworks_filename.clear ();
              }
            break;
          }

        case 24:
          {
            if (i < rc.lines.size ())
              {
                editor_font_name = rc.lines[i];
              }
            else
              {
                editor_font_name = "Sans 14";
              }
            break;
          }

        case 25:
          {
            if (i < rc.lines.size ())
              {
                import_references_searchword = rc.lines[i];
              }
            else
              {
                import_references_searchword.clear ();
              }
            break;
          }

        case 26:
          {
            if (i < rc.lines.size ())
              {
                project = rc.lines[i];
              }
            else
              {
                project.clear ();
              }
            break;
          }

        case 27:
          {
            if (i < rc.lines.size ()) {
              case_sensitive_search = convert_to_bool (rc.lines[i]);
            }
            else {
              case_sensitive_search = false;
            }
            break;
          }

        case 28:
          {
            if (i < rc.lines.size ()) {
              paper_format = rc.lines[i];
            }
            else {
              paper_format = "A4";
            }
            break;
          }

        case 29:
          {
            if (i < rc.lines.size ()) {
              paper_width = convert_to_double (rc.lines[i]);
            }
            else {
              paper_width = 21.0;
            }
            break;
          }

        case 30:
          {
            if (i < rc.lines.size ()) {
              paper_height = convert_to_double (rc.lines[i]);
            }
            else {
              paper_height = 29.7;
            }
            break;
          }

        case 31:
          {
            if (i < rc.lines.size ()) {
              paper_left_margin = convert_to_double (rc.lines[i]);
            }
            else {
              paper_left_margin = 2;
            }
            break;
          }

        case 32:
          {
            if (i < rc.lines.size ()) {
              paper_right_margin = convert_to_double (rc.lines[i]);
            }
            else {
              paper_right_margin = 2;
            }
            break;
          }

        case 33:
          {
            if (i < rc.lines.size ()) {
              paper_top_margin = convert_to_double (rc.lines[i]);
            }
            else {
              paper_top_margin = 2;
            }
            break;
          }

        case 34:
          {
            if (i < rc.lines.size ()) {
              paper_bottom_margin = convert_to_double (rc.lines[i]);
            }
            else {
              paper_bottom_margin = 2;
            }
            break;
          }

        case 35:
          {
            if (i < rc.lines.size ()) {
              java_home = rc.lines[i];
            }
            else {
              java_home = java_home_environment_variable();
            }
            break;
          }

        case 36:
          {
            if (i < rc.lines.size ()) {
              printcoverpage = convert_to_bool (rc.lines[i]);
            }
            else {
              printcoverpage = true;
            }
            break;
          }

        case 37:
          {
            if (i < rc.lines.size ()) {
              fop_home = rc.lines[i];
            }
            else {
              fop_home = "";
            }
            break;
          }

        case 38:
          {
            if (i < rc.lines.size ()) {
              printdate = convert_to_bool (rc.lines[i]);
            }
            else {
              printdate = true;
            }
            break;
          }

        case 39:
          {
            if (i < rc.lines.size ()) {
              print_changes_only = convert_to_bool (rc.lines[i]);
            }
            else {
              print_changes_only = false;
            }
            break;
          }

        case 40:
          {
            if (i < rc.lines.size ()) {
              project_to_compare_with = rc.lines[i];
            }
            else {
              project_to_compare_with.clear();
            }
            break;
          }


          
          
          
          
          
        }
    }
}


Configuration::~Configuration ()
{
  // If the object goes out of scope, it saves the configuration.
  vector < string > output;
  output.push_back (VERSION);
  output.
    push_back
    ("There is no need for editing this file, because it is maintained by bibledit");
  output.push_back (edit_note_standard_text_one);
  output.push_back (edit_note_standard_text_two);
  output.push_back (edit_note_standard_text_three);
  output.push_back (convert_to_string (screen_width));
  output.push_back (convert_to_string (screen_height));
  output.push_back (convert_to_string (window_width));
  output.push_back (convert_to_string (window_height));
  output.push_back (convert_to_string (window_x_position));
  output.push_back (convert_to_string (window_y_position));
  output.push_back (convert_to_string (hpane_position));
  output.push_back (convert_to_string (vpane_position));
  output.push_back (book_opened);
  output.push_back (chapter_opened);
  output.push_back (verse_opened);
  output.push_back (edit_note_standard_text_four);
  output.push_back (convert_to_string (searchspecial_containword));
  output.push_back (find_searchword);
  output.push_back (find_replaceword);
  output.push_back (references_file);
  output.push_back (convert_to_string (companion_enabled));
  output.push_back (convert_to_string (bibletime_enabled));
  output.push_back (export_to_bibleworks_filename);
  output.push_back (editor_font_name);
  output.push_back (import_references_searchword);
  output.push_back (project);
  output.push_back (convert_to_string (case_sensitive_search));
  output.push_back (paper_format);
  output.push_back (convert_to_string (paper_width));
  output.push_back (convert_to_string (paper_height));
  output.push_back (convert_to_string (paper_left_margin));
  output.push_back (convert_to_string (paper_right_margin));
  output.push_back (convert_to_string (paper_top_margin));
  output.push_back (convert_to_string (paper_bottom_margin));
  output.push_back (java_home);
  output.push_back (convert_to_string (printcoverpage));
  output.push_back (fop_home);
  output.push_back (convert_to_string (printdate));
  output.push_back (convert_to_string (print_changes_only));
  output.push_back (project_to_compare_with);

  write_lines (bibleditrc (), output);
}


string
Configuration::bibleditrc ()
{
  // Returns the full name of the ~/<root>/settings configuration file.
  // E.g.: /home/joe/.bibledit/settings
  string bibledit_directory = directories_get_root ();
  return g_build_filename (bibledit_directory.c_str(), "settings", NULL);
}
